/** @file
 * @brief SerializeServiceContainer class header. This class holds Service objects in a list for serialization.
 *
 *
 *
 * @copyright Intra2net AG
 * @license GPLv2
*/

#ifndef SERIALIZESERVICECONTAINER_H
#define SERIALIZESERVICECONTAINER_H

#include "service.hpp"
#include "logger.hpp"

#include <boost/serialization/list.hpp>
#include <boost/serialization/vector.hpp>
#include <boost/serialization/map.hpp>
#include <boost/serialization/shared_ptr.hpp>
#include <boost/serialization/export.hpp>

#include <boost/shared_ptr.hpp>
#include <list>

#include "service_dhs.hpp"
#include "service_ods.hpp"
#include "service_dyndns.hpp"
#include "service_dyns.hpp"
#include "service_easydns.hpp"
#include "service_tzo.hpp"
#include "service_zoneedit.hpp"
#include "service_gnudip.hpp"
#include "service_gnudip_fullhostname.hpp"


class SerializeServiceContainer
{

private:

    std::list<Service::Ptr> ContainingServices;

    friend class boost::serialization::access;
    template<class Archive>
    void serialize(Archive & ar, const unsigned int version)
    {
        ar & ContainingServices;
    }

public:

    typedef boost::shared_ptr<SerializeServiceContainer> Ptr;

    SerializeServiceContainer();

    ~SerializeServiceContainer();

    void add_service(Service::Ptr service);

    std::list<Service::Ptr> get_containing_services() const;

};

#endif
